HotFnPanic

Struct HotFnPanic 

pub struct HotFnPanic { /* private fields */ }
A panic issued by the call function if the caller would be stale if called. This causes an unwind to the next call instance that can properly handle the panic and retry the call.

This technique allows Subsecond to provide hot-reloading of codebases that don’t have a runtime integration.