pub unsafe fn get_jump_table() -> Option<&'static JumpTable>Expand description
Get the current jump table, if it exists.
This will return None if no jump table has been set yet.
Safety
The JumpTable returned here is a pointer into a leaked box. While technically this reference is
valid, we might change the implementation to invalidate the pointer between hotpatches.
You should only use this lifetime in temporary contexts - not across hotpatches!