pub fn register_handler(handler: Arc<dyn Fn() + Send + Sync + 'static>)Expand description
Register a function that will be called whenever a patch is applied.
This handler will be run immediately after the patch library is loaded into the process and the JumpTable has been set.